summaryrefslogtreecommitdiffstats
path: root/include/smsc_lpc47m.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/smsc_lpc47m.h')
-rw-r--r--include/smsc_lpc47m.h29
1 files changed, 25 insertions, 4 deletions
diff --git a/include/smsc_lpc47m.h b/include/smsc_lpc47m.h
index 32b069df6f..419643f89f 100644
--- a/include/smsc_lpc47m.h
+++ b/include/smsc_lpc47m.h
@@ -7,14 +7,35 @@
#ifndef _SMSC_LPC47M_H_
#define _SMSC_LPC47M_H_
+/* I/O address of LPC47M */
+#define LPC47M_IO_PORT 0x2e
+
+/* Logical device number */
+#define LPC47M_FDC 0 /* Floppy */
+#define LPC47M_SP2 2 /* Serial Port 2 */
+#define LPC47M_PP 3 /* Parallel Port */
+#define LPC47M_SP1 4 /* Serial Port 1 */
+#define LPC47M_KBC 7 /* Keyboard & Mouse */
+#define LPC47M_PME 10 /* Power Control */
+
/**
* Configure the base I/O port of the specified serial device and enable the
* serial device.
*
- * @dev: High 8 bits = Super I/O port, low 8 bits = logical device number.
- * @iobase: Processor I/O port address to assign to this serial device.
- * @irq: Processor IRQ number to assign to this serial device.
+ * @dev: high 8 bits = super I/O port, low 8 bits = logical device number
+ * @iobase: processor I/O port address to assign to this serial device
+ * @irq: processor IRQ number to assign to this serial device
+ */
+void lpc47m_enable_serial(uint dev, uint iobase, uint irq);
+
+/**
+ * Configure the specified keyboard controller device and enable the keyboard
+ * controller device.
+ *
+ * @dev: high 8 bits = Super I/O port, low 8 bits = logical device number
+ * @irq0: processor IRQ number to assign to keyboard
+ * @irq1: processor IRQ number to assign to mouse
*/
-void lpc47m_enable_serial(u16 dev, u16 iobase, u8 irq);
+void lpc47m_enable_kbc(uint dev, uint irq0, uint irq1);
#endif /* _SMSC_LPC47M_H_ */